Helpful commands - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Helpful commands

Important

These commands require Bash

`./bin/build-dev`

  Build the development environment. This should be run within a Python virtual environment.

`./bin/build-dev-npm`

  Build the npm components of the development environment.

`./bin/build-dev-pip`

  Build the pip components of the development environment. This should be run within a Python virtual environment.

`./bin/build-setuptools`

  Build setuptools packages.

`./bin/clean-build`

  Clean build artifacts.

`./bin/fix`

  Automatically fix as many problems as possible.

`./bin/test`

  Run all tests.

`./bin/test-build-setuptools`

  Test building setuptools packages.

`./bin/test-eslint`

  Run ESLint tests.

`./bin/test-mypy`

  Run mypy tests.

`./bin/test-pytest`

  Run pytest tests.

`./bin/test-ruff`

  Run Ruff tests.

`./bin/test-shellcheck`

  Run ShellCheck tests.

`./bin/test-stylelint`

  Run Stylelint tests.